
-- sorry, monks only
if select(2, UnitClass("player")) ~= "MONK" then
    return
end

local locDB = ChiEnergyBar.locDB

--------------------------------------------------------------------------------------------
--------------------------[[  Frame create functions ]]-------------------------------------
--------------------------------------------------------------------------------------------

function ChiEnergyBar:CreateFrame(frName)

	local frame = CreateFrame("Frame", frName, UIParent)
	frame:EnableMouse(true)
	frame:SetMovable(true)
	frame:SetResizable(true)
	return frame

end

function ChiEnergyBar:HandleChiPointFrames(cpCount, showFr)

	for i = 0, cpCount - 1 do
		local frIndex = i + 1
		local fr = _G["CPFrame"..frIndex]
		local h = ChiEnergyBarDB.cp.size.h
		local cpSetPoint = i * (h + ChiEnergyBarDB.cp.spacing)
		fr:SetSize(h, h)
		fr:SetPoint("LEFT", cpSetPoint, 0)
		if showFr then
			fr:Show()
		end
	end

end

function ChiEnergyBar:MakeMovableSizable(frame, id, blocker)

	local function SaveSetPoints()

		ChiEnergyBarDB[id].coords.xPos = frame:GetLeft()
		ChiEnergyBarDB[id].coords.yPos = frame:GetBottom()

	end

	frame:IsClampedToScreen(true)
	frame:SetMaxResize(1400, 100)
	frame:SetMinResize(80, 14)
	if frame == "TB" then
		frame:SetMaxResize(64, 64)
		frame:SetMinResize(24, 24)
	end
	frame:RegisterForDrag("LeftButton", "RightButton")
	frame:SetScript("OnMouseDown", function (self, button)
		if not ChiEnergyBarDB[blocker] then
			if button == "RightButton" then
				local bg = {
					bgFile = "Interface\\TutorialFrame\\TutorialFrameBackground",
					edgeFile = ChiEnergyBarDB[id].border.path,
					tile = false,
					tileSize = 8,
					edgeSize = ChiEnergyBarDB[id].border.edgeSize,
					insets = {
						left = 3,
						right = 4,
						top = 4,
						bottom = 3,
					}
				}
				if id == "cp" then
					frame:SetMaxResize(340, 64)
					locDB.doChiPointsUpdate = false
					bg.edgeFile = nil
					frame:SetBackdrop(bg)
					ChiEnergyBar:HandleChiPointFrames(locDB.cpMax, true)
				else
					bg.insets = {
						left = 0,
						right = 0,
						top = 0,
						bottom = 0,
					}
					if id == "eb" then
						EnergyStatusBar:Hide()
						EnergyStatusBar.bg:Hide()
					end
					frame:SetBackdrop(bg)
				end
				local selfWidth = self:GetWidth()
				local selfHeight = self:GetHeight()
				local xCenter, yCenter = self:GetCenter()
				local xPos, yPos = GetCursorPosition()
				local selfScale, parentScale = self:GetScale(), UIParent:GetScale()
				xPos, yPos = xPos / parentScale,  yPos / parentScale
				xCenter, yCenter = xCenter * selfScale, yCenter * selfScale
				xCenter, yCenter = xPos - xCenter, yPos - yCenter
				xCenter = xCenter / selfWidth * selfHeight
				if (abs(xCenter) > abs(yCenter)) then
					locDB.xSized = true
					locDB.ySized = false
					if (xCenter > 0) then
						self:StartSizing("RIGHT")
					else
						self:StartSizing("LEFT")
					end
				else
					locDB.xSized = false
					locDB.ySized = true
					if (yCenter > 0) then
						self:StartSizing("TOP")
					else
						self:StartSizing("BOTTOM")
					end
				end
			else
				if id == "cp" then
					local _, _, cpCur, _ = ChiEnergyBar:UpdateEnergy()
					local shiftKey = IsShiftKeyDown()
					if shiftKey then
						locDB.doChiPointsUpdate = true
						ChiEnergyBar:HandleChiPointFrames(cpCur, true)
					else
						locDB.doChiPointsUpdate = false
						ChiEnergyBar:HandleChiPointFrames(locDB.cpMax, true)
					end
				end
				self:StartMoving()
			end
		end
	end)
	frame:SetScript("OnMouseUp", function (self, button)
		self:StopMovingOrSizing()
		if button == "RightButton" then
			local bg = {
				bgFile = nil,
				edgeFile = ChiEnergyBarDB[id].border.path,
				tile = false,
				tileSize = 8,
				edgeSize = ChiEnergyBarDB[id].border.edgeSize,
				insets = {
					left = 3,
					right = 4,
					top = 4,
					bottom = 3,
				}
			}
			ChiEnergyBarDB[id].size.w = floor(self:GetWidth() + 0.5)
			ChiEnergyBarDB[id].size.h = floor(self:GetHeight() + 0.5)
			if id == "eb" then
				EnergyBarText:SetTextHeight(ChiEnergyBarDB.eb.font.height)
 				EnergyStatusBar:SetSize(ChiEnergyBarDB[id].size.w - ChiEnergyBarDB[id].border.adjW, ChiEnergyBarDB[id].size.h - ChiEnergyBarDB[id].border.adjH)
				EnergyStatusBar:SetFrameLevel(EnergyStatusBar:GetParent():GetFrameLevel() - 1)
				EnergyStatusBar.bg:SetTexture(0, 0, 0, 0.4)
				EnergyStatusBar.bg:SetAllPoints(EnergyStatusBar)
				EnergyStatusBar:Show()
				EnergyStatusBar.bg:Show()
			elseif id == "cp" then
				bg.edgeFile = nil
 				locDB.doChiPointsUpdate = true
				ChiEnergyBarDB[id].size.w, ChiEnergyBarDB[id].size.h = ChiPointsBar:GetWidth(), ChiPointsBar:GetHeight()
				if locDB.xSized then
					ChiEnergyBarDB[id].size.h = (ChiEnergyBarDB[id].size.w - (ChiEnergyBarDB.cp.spacing * (locDB.cpMax - 1))) / locDB.cpMax
				else
					ChiEnergyBarDB[id].size.w = (ChiEnergyBarDB[id].size.h * locDB.cpMax) + (ChiEnergyBarDB.cp.spacing * (locDB.cpMax -1))
				end
				ChiEnergyBar:HandleChiPointFrames(locDB.cpMax, false)
			else
				if locDB.xSized then
					ChiEnergyBarDB[id].size.h = ChiEnergyBarDB[id].size.w
				else
					ChiEnergyBarDB[id].size.w = ChiEnergyBarDB[id].size.h
				end
			end
			frame:SetBackdrop(bg)
			frame:SetSize(ChiEnergyBarDB[id].size.w, ChiEnergyBarDB[id].size.h)
		else
			local shiftKey = IsShiftKeyDown()
			if shiftKey then
				ChiEnergyBar:BarLockToggle(id)
			else
				if id == "cp" then
					local _, _, cpCur, _ = ChiEnergyBar:UpdateEnergy()
					locDB.doChiPointsUpdate = true
					ChiEnergyBar:HandleChiPointFrames(cpCur, true)
				end
				SaveSetPoints()
			end
		end
		locDB.cpUpdate = true
		ChiEnergyBar:UpdateBar()
	end)

end

function ChiEnergyBar:GetEnergyString()

	local enCur, enMax, _, _, _ = ChiEnergyBar:UpdateEnergy()
	local energyStr = enCur.."/"..enMax
	if ChiEnergyBarDB.ebNoMaxEnergy then
		energyStr = enCur
	end
	if not ChiEnergyBarDB.ebShowEnergy then
		energyStr = nil
	end
	return energyStr

end

---------------------------------------------------------------------------------------------
--------------------------[[  Chi points frame  ]]-------------------------------------------
---------------------------------------------------------------------------------------------

function ChiEnergyBar:CreateChiPointsBar()

	local bg = {
		bgFile = ChiEnergyBarDB.cp.texture.path,
		edgeFile = ChiEnergyBarDB.cp.border.path,
		tile = false,
		tileSize = 8,
		edgeSize = ChiEnergyBarDB.cp.border.edgeSize,
		insets = {
			left = 3,
			right = 3,
			top = 3,
			bottom = 3,
		}
	}
	local _, _, cpCur, _ = ChiEnergyBar:UpdateEnergy()
	local cpF = "CPFrame"
	local w, h = ChiEnergyBarDB.cp.size.w, ChiEnergyBarDB.cp.size.h
	local xPos, yPos = ChiEnergyBarDB.cp.coords.xPos or (UIParent:GetWidth() / 2) - (w / 2), ChiEnergyBarDB.cp.coords.yPos or (UIParent:GetHeight() / 2) - 200
	local cpBar = ChiPointsBar
	cpBar:SetSize(w, h)
	cpBar:SetPoint("BOTTOMLEFT", xPos, yPos)
	for i = 0, locDB.cpTot - 1 do
		local frIndex = i + 1
		local frName = cpF..frIndex
		local cpFrame = CreateFrame("Frame", frName, cpBar)
		local cpSetPoint = i * (h + ChiEnergyBarDB.cp.spacing)
		if ChiEnergyBarDB.cpShowAllways then
			if not ChiEnergyBarDB.cpShowAllwaysWithTexture then
				if ChiEnergyBarDB.cp.border.txt == locDB.border[1].txt then
 					bg.bgFile = "Interface\\Tooltips\\UI-Tooltip-Background"
				else
					bg.bgFile = nil
				end
			else
				bg.bgFile = ChiEnergyBarDB.cp.texture.path
			end
			cpFrame:SetBackdrop(bg)
			if frIndex <= locDB.cpMax then
				cpFrame:Show()
			else
				cpFrame:Hide()
			end
		else
			cpFrame:SetBackdrop(bg)
			cpFrame:SetBackdropColor(ChiEnergyBarDB.cp.color.r, ChiEnergyBarDB.cp.color.g, ChiEnergyBarDB.cp.color.b, ChiEnergyBarDB.cp.color.a)
			cpFrame:Hide()
		end
		cpFrame:SetSize(h, h)
		cpFrame:SetPoint("LEFT", cpSetPoint, 0)
	end
	ChiEnergyBar:MakeMovableSizable(ChiPointsBar, "cp", "cpLock")

end

---------------------------------------------------------------------------------------------
--------------------------[[  Energy bar frame  ]]-------------------------------------------
---------------------------------------------------------------------------------------------

function ChiEnergyBar:CreateEnergyBar()

	local bg = {
		bgFile = nil,
		edgeFile = ChiEnergyBarDB.eb.border.path,
		tile = false,
		tileSize = 8,
		edgeSize = ChiEnergyBarDB.eb.border.edgeSize,
		insets = {
			left = 3,
			right = 4,
			top = 4,
			bottom = 3,
		}
	}
	local w, h = ChiEnergyBarDB.eb.size.w, ChiEnergyBarDB.eb.size.h
	local xPos, yPos = ChiEnergyBarDB.eb.coords.xPos or (UIParent:GetWidth() / 2) - (w / 2), ChiEnergyBarDB.eb.coords.yPos or (UIParent:GetHeight() / 2) - 220
	local _, enMax, _, _ = ChiEnergyBar:UpdateEnergy()
	local energyStr = ChiEnergyBar:GetEnergyString()
	EnergyBar:SetSize(w, h)
	EnergyBar:SetBackdrop(bg)
	EnergyBar:SetPoint("BOTTOMLEFT", xPos, yPos)
	local enFont = CreateFont("EnergyBarFont")
	enFont:SetFont(ChiEnergyBarDB.eb.font.path, ChiEnergyBarDB.eb.font.height, "OUTLINE")
	local enText = EnergyBar:CreateFontString("EnergyBarText", "OVERLAY", "EnergyBarFont")
	enText:SetPoint(ChiEnergyBarDB.eb.fontSetPoints.setPoint, ChiEnergyBarDB.eb.fontSetPoints.hPadding, 0)
	enText:SetText(energyStr)
	local enStatBar = CreateFrame("StatusBar", "EnergyStatusBar", EnergyBar)
	enStatBar:SetSize(w - ChiEnergyBarDB.eb.border.adjW, h - ChiEnergyBarDB.eb.border.adjH)
	enStatBar:SetPoint("CENTER", 0, 0)
	enStatBar:SetFrameLevel(enStatBar:GetParent():GetFrameLevel() - 1)
	enStatBar.bg = enStatBar:CreateTexture("EnergyStatusBarBg", "BACKGROUND")
	enStatBar.bg:SetSize(enStatBar:GetWidth(), enStatBar:GetHeight())
	enStatBar.bg:SetTexture(0, 0, 0, 0.4)
	enStatBar.bg:SetAllPoints(enStatBar)
	enStatBar.texture = enStatBar:CreateTexture("EnergyStatusBarTexture", "BACKGROUND")
	enStatBar.texture:SetTexture(ChiEnergyBarDB.eb.texture.path)
 	enStatBar:SetStatusBarTexture(enStatBar.texture)
	enStatBar:SetStatusBarColor(ChiEnergyBarDB.eb.color.r, ChiEnergyBarDB.eb.color.g, ChiEnergyBarDB.eb.color.b, ChiEnergyBarDB.eb.color.a)
	enStatBar:SetMinMaxValues(0, enMax)
	ChiEnergyBar:MakeMovableSizable(EnergyBar, "eb", "ebLock")

end

---------------------------------------------------------------------------------------------
--------------------------[[  Tigereye brew frame  ]]----------------------------------------
---------------------------------------------------------------------------------------------

function ChiEnergyBar:CreateTigereyeBrewFrame()

	local bg = {
		bgFile = nil,
		edgeFile = ChiEnergyBarDB.tb.border.path,
		tile = false,
		tileSize = 8,
		edgeSize = ChiEnergyBarDB.tb.border.edgeSize,
		insets = {
			left = 3,
			right = 4,
			top = 4,
			bottom = 3,
		}
	}
	local w, h = ChiEnergyBarDB.tb.size.w, ChiEnergyBarDB.tb.size.h
	local xPos, yPos = ChiEnergyBarDB.tb.coords.xPos or (UIParent:GetWidth() / 2) - (w / 2), ChiEnergyBarDB.tb.coords.yPos or (UIParent:GetHeight() / 2) - 180
	local _, _, _, _, tbCur = ChiEnergyBar:UpdateEnergy()
	TBBar:SetSize(w, h)
	TBBar:SetBackdrop(bg)
	TBBar:SetPoint("BOTTOMLEFT", xPos, yPos)
	local tbFont = CreateFont("TBBarFont")
	tbFont:SetFont(ChiEnergyBarDB.tb.font.path, ChiEnergyBarDB.tb.font.height, "OUTLINE")
	local tbText = TBBar:CreateFontString("TBBarText", "OVERLAY", "TBBarFont")
	tbText:SetPoint("CENTER", 0, "CENTER")
	tbText:SetText(tbCur)
	ChiEnergyBar:MakeMovableSizable(TBBar, "tb", "tbLock")

end

---------------------------------------------------------------------------------------------
--------------------------[[  First time user help frame  ]]---------------------------------
---------------------------------------------------------------------------------------------

function ChiEnergyBar:CreateHelpFrame()

	local bg = {
		bgFile = "Interface\\TutorialFrame\\TutorialFrameBackground",
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
		tile = false,
		tileSize = 8,
		edgeSize = 16,
		insets = {
			left = 3,
			right = 4,
			top = 4,
			bottom = 3,
		}
	}
	local helpFrame = CreateFrame("Frame", "CEBHelpFrame", UIParent)
	helpFrame:SetSize(540, 240)
	helpFrame:SetBackdrop(bg)
	helpFrame:SetPoint("CENTER", 0, -20)
	local closeButton = CreateFrame("Button", nil, CEBHelpFrame, "UIPanelCloseButton")
	closeButton:SetPoint("TOPRIGHT", 3, 2)
	local helpText = helpFrame:CreateFontString("CEBHelpText", "OVERLAY")
	helpText:SetPoint("TOPLEFT", 15, -15)
	helpText:SetFont("Fonts\\ARIALN.TTF", 14)
	helpText:SetJustifyH("LEFT")
	local txtDB = locDB.helpText
	local msg = txtDB.title..txtDB.line1..txtDB.line2..txtDB.slashCom..txtDB.tabSpace..txtDB.toggle1..txtDB.tabSpace..txtDB.toggle2..txtDB.tabSpace..txtDB.toggle3..txtDB.mouse1..txtDB.mouse2..txtDB.mouse3
	helpText:SetText(msg)
	local chkBox = CreateFrame("CheckButton", "CEBHelpCheckButton", CEBHelpFrame, "ChatConfigCheckButtonTemplate")
	chkBox:SetPoint("BOTTOMLEFT", CEBHelpFrame, 15, 10)
	local chkBoxTxt = "CEBHelpCheckButton".."Text"
	local txt = " Don't show this message again"
	_G[chkBoxTxt]:SetFont("Fonts\\ARIALN.TTF", 14)
	_G[chkBoxTxt]:SetText(txt)
	if ChiEnergyBarDB.noHelpText then
		chkBox:SetChecked(true)
	else
		chkBox:SetChecked(false)
	end
	chkBox:SetScript("OnClick", function()
		local ischecked = chkBox:GetChecked()
		if ischecked == 1 then
			ChiEnergyBarDB.noHelpText = true
		else
			ChiEnergyBarDB.noHelpText = false
		end
	end)
	helpFrame:Show()

end
